@@ -1,15 +1,12 @@
 from __future__ import annotations
 
 import argparse
-import sys
 import textwrap
-from shutil import get_terminal_size
 
 from pdm import termui
 from pdm._types import SearchResults
 from pdm.cli.commands.base import BaseCommand
 from pdm.cli.options import verbose_option
-from pdm.environments import BareEnvironment
 from pdm.models.working_set import WorkingSet
 from pdm.project import Project
 from pdm.utils import normalize_name
@@ -28,30 +25,25 @@ def print_results(
     for hit in hits:
         name = hit.name
         summary = hit.summary or ""
-        latest = hit.version or ""
         if terminal_width is not None:
             target_width = terminal_width - name_column_width - 5
             if target_width > 10:
                 # wrap and indent summary to fit terminal
                 summary = ("\n" + " " * (name_column_width + 2)).join(textwrap.wrap(summary, target_width))
-        current_width = len(name) + len(latest) + 4
+        current_width = len(name) + 1
         spaces = " " * (name_column_width - current_width)
-        line = f"[req]{name}[/] ([warning]{latest}[/]){spaces} - {summary}"
+        line = f"[req]{name}[/]{spaces} - {summary}"
         try:
             ui.echo(line)
             if normalize_name(name) in working_set:
                 dist = working_set[normalize_name(name)]
-                if dist.version == latest:
-                    ui.echo(f"  INSTALLED: {dist.version} (latest)")
-                else:
-                    ui.echo(f"  INSTALLED: {dist.version}")
-                    ui.echo(f"  LATEST:    {latest}")
+                ui.echo(f"  INSTALLED: {dist.version}")
         except UnicodeEncodeError:
             pass
 
 
 class Command(BaseCommand):
-    """Search for PyPI packages"""
+    """[DEPRECATED] Search for PyPI packages"""
 
     arguments = (verbose_option,)
 
@@ -59,10 +51,8 @@ class Command(BaseCommand):
         parser.add_argument("query", help="Query string to search")
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
-        project.environment = BareEnvironment(project)
-        result = project.get_repository().search(options.query)
-        terminal_width = None
-        if sys.stdout.isatty():
-            terminal_width = get_terminal_size()[0]
-        working_set = project.environment.get_working_set()
-        print_results(project.core.ui, result, working_set, terminal_width)
+        project.core.ui.warn(
+            "Since pypi.org no longer supports search API, this command is deprecated and will be removed in future versions. "
+            "Please visit `https://pypi.org` in the browser to search for packages.",
+        )
+        return
